==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangingArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescriptionMetadata } from "./WebActiveStepChangingArgsDetailDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescription } from "./WebActiveStepChangingArgsEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveStepChangingArgsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangingArgsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangingArgsEventArgsDescriptionMetadata.a == null) {
                WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangingArgsEventArgsDescriptionMetadata.c(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
            WebActiveStepChangingArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebActiveStepChangingArgsDetail");
        }
        static d(a) {
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.b(a);
            a.ad("WebActiveStepChangingArgsEventArgs", () => new WebActiveStepChangingArgsEventArgsDescription());
            a.ac("WebActiveStepChangingArgsEventArgs", WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangingArgsEventArgsDescriptionMetadata, 'WebActiveStepChangingArgsEventArgsDescriptionMetadata');
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangingArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescriptionMetadata } from "./WebActiveStepChangingArgsDetailDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescription } from "./WebActiveStepChangingArgsEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveStepChangingArgsEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangingArgsEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangingArgsEventArgsDescriptionMetadata.a == null) {
                WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangingArgsEventArgsDescriptionMetadata.c(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
            WebActiveStepChangingArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebActiveStepChangingArgsDetail");
        }
        static d(a) {
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.b(a);
            a.ae("WebActiveStepChangingArgsEventArgs", () => new WebActiveStepChangingArgsEventArgsDescription());
            a.ad("WebActiveStepChangingArgsEventArgs", WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangingArgsEventArgsDescriptionMetadata, 'WebActiveStepChangingArgsEventArgsDescriptionMetadata');
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsEventArgsDescriptionMetadata;
})();
